@@ -9,14 +9,12 @@
 # with:
 #  #define STUB(x) x
 
-bindgen \
-	--opaque-type std::.* \
-	--allowlist-type cocos2d::.* \
-	--allowlist-function cocos2d::.* \
+bindgen --rust-target nightly --opaque-type std::.* --allowlist-type cocos2d::.* --allowlist-function cocos2d::.* \
 	--allowlist-var cocos2d::.* \
 	-osrc/bindings.rs \
 	\
 	wrapper.h -- \
+	-target i686-pc-windows-msvc \
 	-xc++ \
 	-Icocos-headers/cocos2dx \
 	-Icocos-headers/cocos2dx/include \
